pub struct ForwardedHeaderConfig {
pub by: ForwardeeMode,
pub for: ForwardeeMode,
pub host: bool,
pub proto: bool,
}Expand description
Configuration for the Forwarded header.
Fields
by: ForwardeeModeThe mode for the by field of the Forwarded header.
for: ForwardeeModeThe mode for the for field of the Forwarded header.
host: boolWhether to include the host field in the Forwarded header.
proto: boolWhether to include the proto field in the Forwarded header.
Implementations
Sourceimpl ForwardedHeaderConfig
impl ForwardedHeaderConfig
Sourcepub fn from_request<B>(&self, request: &Request<B>) -> Forwarded
pub fn from_request<B>(&self, request: &Request<B>) -> Forwarded
Build a Forwarded header from a request.